@@ -1,7 +1,6 @@
 import logging
 import os
 import sys
-from os.path import exists
 
 from .base_lock import DistributedLock
 from .utils import LockUtils
@@ -35,7 +34,7 @@ class FCNTLFileLock(DistributedLock):
     # Even if lock is acquired by another process, can_execute_task method
     # of the base class just returns True, but try_acquire_lock fails.
 
-    def __init__(self, lock_file):
+    def __init__(self, lock_file: str):
 
         # You can't do this at the top of the file. Reason is, even if
         # FCNTLFileLock never gets instantiated, moment file_lock gets
@@ -45,10 +44,11 @@ class FCNTLFileLock(DistributedLock):
         # only when SCHEDULER_LOCK_TYPE is 'File'.
         # Other option will be to conditionally import file_lock module
         # based on value of SCHEDULER_LOCK_TYPE which is not so nice.
-        # Also, since 'fcntl' module is now present at the class level,
+        # Also, since 'fcntl' module is now present at the instance level,
         # we access it in all subsequent methods using 'self.fcntl'.
         try:
             import fcntl
+
             logger.debug("Module %s imported successfully!", fcntl.__name__)
         except ModuleNotFoundError as e:
             logger.error(f"ModuleNotFoundError: {e}")
@@ -62,7 +62,7 @@ class FCNTLFileLock(DistributedLock):
     def try_acquire_lock(self) -> True:
         fd = None
         try:
-            f_exists = exists(self.lock_file)
+            f_exists = os.path.exists(self.lock_file)
             open_mode = os.O_RDWR if f_exists else os.O_RDWR | os.O_CREAT
             fd = os.open(self.lock_file, open_mode, 0o600)
 
@@ -73,13 +73,14 @@ class FCNTLFileLock(DistributedLock):
             # Source: https://manpages.debian.org/bullseye/manpages-dev/flock.2.en.html
 
             self.fcntl.flock(fd, self.fcntl.LOCK_EX | self.fcntl.LOCK_NB)
-            owner = LockUtils.get_lock_owner()
+            owner = LockUtils.get_current_instance_name()
             logger.debug(f"{owner} owns lock on file {self.lock_file}")
-            owner_bytes = bytes(owner + '\n', 'utf-8')
+            owner_bytes = bytes(owner + "\n", "utf-8")
             os.write(fd, owner_bytes)
             os.truncate(fd, len(owner_bytes))
             self.lock_file_fd = fd
-        except (IOError, OSError):
+        except (IOError, OSError) as e:
+            logger.debug(e)
             if fd is not None:
                 logger.debug(f"Lock not obtained, closing {fd}, pid: {os.getpid()}")
                 os.close(fd)
@@ -88,16 +89,31 @@ class FCNTLFileLock(DistributedLock):
 
     # This method actually never gets called.
     # Lock is released only when lock owner dies, shuts down etc.
+    # Also, following code is most probably buggy
     def release(self) -> None:
 
+        if not self.lock_file_fd:
+            f_exists = os.path.exists(self.lock_file)
+            open_mode = os.O_RDWR if f_exists else os.O_RDWR | os.O_CREAT
+            fd = os.open(self.lock_file, open_mode, 0o600)
+        else:
+            fd = self.lock_file_fd
         # Do not remove the lockfile:
         #
         #   https://github.com/benediktschmitt/py-filelock/issues/31
         #   https://stackoverflow.com/questions/17708885/flock-removing-locked-file-without-race-condition
-        self.fcntl.flock(self.lock_file_id, self.fcntl.LOCK_UN)
-        os.close(self.lock_file_id)
+        self.fcntl.flock(fd, self.fcntl.LOCK_UN | self.fcntl.LOCK_NB)
+        os.close(fd)
 
     def renew_lease(self) -> bool:
         # We can possibly use the concept of lease here, by maintaining the
         # validity of the lock in the file. But for now, we don't.
-        return True
+        # We just return true if the lock file is present, else false.
+        return bool(os.path.exists(self.lock_file))
+
+    def get_current_owner(self) -> str:
+        if os.path.exists(self.lock_file):
+            with open(self.lock_file) as f:
+                return f.read().strip()
+        else:
+            return "Lock file does not exist. Unable to fetch lock owner."
