@@ -18,10 +18,10 @@ class LockUtils:
         return hex(uuid.getnode())
 
     @classmethod
-    def get_lock_owner(cls) -> str:
+    def get_current_instance_name(cls) -> str:
         """
-        Returns name of the lock owner in the format:
-        process_id:mac_id:hostname
+        Returns name of the current instance in the format: process_id:mac_id:hostname.
+        In case the current instance gets the lock, this will be the lock owner name.
 
         With containers, chances of process id being same are quite high.
         In fact, if your program is main docker process, its process id will mostly be 1.
@@ -33,4 +33,4 @@ class LockUtils:
     @staticmethod
     def get_epochtime_in_millis() -> int:
         MILLION = 1000000
-        return int(time.time_ns()/MILLION)
+        return int(time.time_ns() / MILLION)
